dnl ESA (C) 2000-2020
dnl
dnl This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
dnl
dnl    SAS is free software: you can redistribute it and/or modify
dnl    it under the terms of the GNU General Public License as published by
dnl    the Free Software Foundation, either version 3 of the License, or
dnl    (at your option) any later version.
dnl
dnl    SAS is distributed in the hope that it will be useful,
dnl    but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
dnl    GNU General Public License for more details.
dnl
dnl    You should have received a copy of the GNU General Public License
dnl    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
dnl
dnl -----------------------------------------------------
dnl Extra autoconfig macros used to configure the XMM SAS
dnl -----------------------------------------------------
dnl

dnl
dnl List of defined macros
dnl
dnl - AC_CHECK_ENV
dnl - AC_TRY_RUN_SCRIPT
dnl - AX_FTOOLS_VERSION
dnl - AC_TRY_PERL5
dnl - AC_TRY_LINK_F90
dnl - AC_TRY_COMPILE_F90
dnl - AC_TRY_LINK_GFORTRAN
dnl - AC_TRY_COMPILE_GFORTRAN
dnl


dnl --------------------------------------------------------------
dnl AC_CHECK_ENV(VARIABLE [, ACTION-IF-SET [, ACTION_IF_NOT_SET]])
dnl --------------------------------------------------------------
dnl Check whether a given environment variable is set.
dnl --------------------------------------------------------------

AC_DEFUN([AC_CHECK_ENV],
[ifelse([$1], , ,[AC_MSG_CHECKING([whether your environment sets $1])
ac_env_var=`echo $1`
ac_env_var_val=`eval echo '$'$1`
AC_CACHE_VAL(ac_env_var$ac_env_var,[if test x$ac_env_var_val != "x" ; then
dnl   AC_MSG_RESULT(yes. $1 = $ac_env_var_val)
   AC_MSG_RESULT(yes)
   ac_$1_set=yes
   ac_env_path=`echo $ac_env_var_val | tr ':' ' '`
   ifelse([$2], , ,[$2])
 else
   AC_MSG_RESULT(no)
   ac_$1_set=no
   ac_env_path=
   ifelse([$3], , ,[$3])
 fi
])
]
) ] )

dnl
dnl ----------------------------------------------------------------------
dnl AC_TRY_RUN_SCRIPT(script, [[action-if-ok] [, action-if-not-ok]])
dnl ----------------------------------------------------------------------
dnl

define(AC_FD_SCRIPT, 5)
AC_DEFUN(AC_TRY_RUN_SCRIPT,
         [echo [$1] > conftest.script 
if chmod +x conftest.script && (./conftest.script; exit) 2>/dev/null
then
dnl Don't remove the temporary files here, so they can be examined.
  ifelse([$2], , :, [$2])
else
  echo "configure: failed program was:" >&AC_FD_SCRIPT
  cat conftest.script >&AC_FD_SCRIPT
ifelse([$3], , , [  rm -fr conftest.script
  $3
])dnl
fi

rm -fr conftest.script])


dnl
dnl -----------------------------------------------------------------
dnl FTOOLS specific macros
dnl 
dnl Checks for the existence of a given version of FTOOLS as part of
dnl HEASOFT. 
dnl -----------------------------------------------------------------
dnl

dnl
dnl AX_FTOOLS_VERSION
dnl

AC_DEFUN(AX_FTOOLS_VERSION,
         [ax_ftools_version=`${FVERSION:-fversion} | cut -dV -f 2`
AC_MSG_CHECKING([that FTOOLS is version $1 or better])
ax_have_this=`echo $ax_ftools_version | tr -ds '.' ''`
ax_want_that=`echo $1 | tr -ds '.' ''`
if test $ax_have_this -ge $ax_want_that  ; then
  AC_MSG_RESULT([($ax_ftools_version) yes])
  ifelse([$2], , ,[$2])
else
  AC_MSG_RESULT([($ax_ftools_version) no])
  AC_MSG_WARN(some SAS tasks require FTOOLS $1 or higher)
  ifelse([$3], , ,[$3])
fi
])


dnl
dnl --------------------
dnl perl specific macros
dnl --------------------
dnl


dnl
dnl AC_TRY_PERL5
dnl

define(AC_FD_PERL, 5)

AC_DEFUN(AC_TRY_PERL5,
        [ac_try_perl="$PERL -e 'require $1;' 1>&AC_FD_PERL"
AC_MSG_CHECKING([if you have perl version $1 or higher])
if AC_TRY_EVAL(ac_try_perl) ; then
AC_MSG_RESULT(yes.)
else
AC_MSG_RESULT(no.)
ifelse([$2], , ,[$2])
fi
])

dnl
dnl ----------------------------------
dnl NAG Fortran 90/95 specific macros
dnl ----------------------------------
dnl

define(AC_FD_F90, 5)

dnl
dnl AC_TRY_LINK_F90(INCLUDES, FUNCTION-BODY,
dnl                [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl Based on the original AC macro. With INCLUDES one should read a
dnl number of USE statements.
dnl



AC_DEFUN(AC_TRY_LINK_F90,
         [ac_link_f90='${F90} -v -c conftest.f90 && ${F90} -v -o conftest $CFLAGS  $LDFLAGS conftest.o $LIBS 1>&AC_FD_F90'
cat > conftest.f90 <<EOF
[$1]
program main
[$2]
END
EOF



if AC_TRY_EVAL(ac_link_f90) && test -s conftest; then
  ifelse([$3], , :, [rm -rf conftest*
  $3])
else
  echo "configure: failed program was:" >&AC_FD_F90
  cat conftest.f90 >&AC_FD_F90
ifelse([$4], , , [  rm -rf conftest*
  $4
])dnl
fi

rm -f conftest*])


dnl
dnl AC_TRY_COMPILE_F90(INCLUDES, FUNCTION-BODY,
dnl
dnl                   [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl

AC_DEFUN(AC_TRY_COMPILE_F90,
         [ac_compile_f90='${F90} -v -c conftest.f90 1>&AC_FD_F90'
cat > conftest.f90 <<EOF
[$1]
program main
[$2]
END
EOF

if AC_TRY_EVAL(ac_compile_f90); then
  ifelse([$3], , :, [rm -rf conftest*
  $3])
else
  echo "configure: failed program was:" >&AC_FD_F90
  cat conftest.f90 >&AC_FD_F90
ifelse([$4], , , [  rm -rf conftest*
  $4
])dnl
fi

rm -f conftest*])


dnl
dnl -----------------------------
dnl GNU Fortran specific macros
dnl -----------------------------
dnl

define(AC_FD_GFORTRAN, 5)

dnl
dnl AC_TRY_LINK_GFORTRAN(INCLUDES, FUNCTION-BODY,
dnl                [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])
dnl Based on the original AC macro. With INCLUDES one should read a
dnl number of USE statements.
dnl

AC_DEFUN(AC_TRY_LINK_GFORTRAN,
         [ac_link_gfortran='${F90} -v -c conftest.f90 && 
                            ${F90} -v -o conftest $CFLAGS $LDFLAGS conftest.o $LIBS 1>&AC_FD_GFORTRAN'
cat > conftest.f90 <<EOF
[$1]
program main
[$2]
END
EOF

if AC_TRY_EVAL(ac_link_gfortran) && test -s conftest; then
  ifelse([$3], , :, [rm -rf conftest*
  $3])
else
  echo "configure: failed program was:" >&AC_FD_GFORTRAN
  cat conftest.f90 >&AC_FD_GFORTRAN
ifelse([$4], , , [  rm -rf conftest*
  $4
])dnl
fi

rm -f conftest*])



dnl
dnl AC_TRY_COMPILE_GFORTRAN(INCLUDES, FUNCTION-BODY,
dnl                         [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]])

AC_DEFUN(AC_TRY_COMPILE_GFORTRAN,
         [ac_compile_gfortran='${F90} -v -c conftest.f90 1>&AC_FD_GFORTRAN'
cat > conftest.f90 <<EOF
[$1]
program main
[$2]
END
EOF

if AC_TRY_EVAL(ac_compile_gfortran); then
  ifelse([$3], , :, [rm -rf conftest*
  $3])
else
  echo "configure: failed program was:" >&AC_FD_GFORTRAN
  cat conftest.f90 >&AC_FD_GFORTRAN
ifelse([$4], , , [  rm -rf conftest*
  $4
])dnl
fi

rm -f conftest*])
