## -*-perl-*-
# ESA (C) 2000-2018 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
##
## XMM SAS package file handling references
##
## Note: synchronize changes here with sasref.sty

package main;
push (@INC,split(':',$ENV{SAS_PATH}));

# --- cross-reference related macros
# Globals: %SASLABEL

# usage: \sasref{Title}{Package}{Label}
# result: refererence to appropriate 'Label' in 'Package' documentation,
#         with accompanying text 'Title'
sub do_cmd_sasref
{
    local($_) = @_;
    my($title,$saspackage,$label);

    &l2hBugFixParsing(\$_);
    if (s/$next_pair_pr_rx//o) {
	$title=$2;
    }
    if (s/$next_pair_pr_rx//o) {
	$saspackage=$2;
    }
    if (s/$next_pair_pr_rx//o) {
	$label=$2;
    }
    return &sasref_label($title,$saspackage,$label,$_);
}

sub sasref_label
{
    my($title,$saspackage,$label,$end)=@_;


    # get the appropriate labels    
    local %external_labels;
    
    local $found;
    foreach (keys %{$SASLABEL{$saspackage}}) {if ($_) {$found=1;last;}}
    if ( $found) {
	%external_labels=%{$SASLABEL{$saspackage}};
    }
    else {
	local ($key,$nosave,%noresave);
	local $URL="../$saspackage";
	require("doc/$saspackage/labels.pl");
	$SASLABEL{$saspackage}=\%external_labels;
    }


    my $ref=$external_labels{$label};
    if ($ref) {
	$ref="<A HREF=$ref>$title</A>";
    }
    else {
	$ref=$title;
    }
    $ref.$end;
}


# --- parameter related macros
sub do_env_sasParamEnv {
    my $explain=join("",
		     "<tr valign=top bgcolor='yellow'>",
		     "<td><b>Parameter</b></td>",
		     "<td><b>Mand </b></td>",
		     "<td><b>Type </b></td>",
		     "<td><b>Default </b></td>",
		     "<td><b>Constraints </b></td>",
		     "</tr>");
		  

    my $attr="width=\"100%\" border=0 cellpadding=0 cellspacing=1";
	
    my $line=join("\n",
		  "\n<br><table $attr>",
		  $explain,
		  "@_",
		  $explain,
		  "</table>\n",);
    $line=~s/\\par\b//mg;
    $line;
}
sub do_cmd_sasParamEnvNote {
    local($_) = @_;
    &l2hBugFixParsing(\$_);
    my $text;
    if (s/$next_pair_pr_rx//o) {$text  =$2 || '&nbsp;';}

    my $line=join("",
		  "\n<tr valign=top><td colspan=5>",
		  "&nbsp;<br>$text&nbsp;</td></tr>\n",
		  $_,
		  );
    $line=~s/\\par\b//mg;
    $line;
}

sub do_cmd_sasParamEnvItem {
    local($_) = @_;
    &l2hBugFixParsing(\$_);

    my($parameter,$mandatory,$type,$default,$constraints,$text);
    if (s/$next_pair_pr_rx//o) {$parameter  =$2;}
    if (s/$next_pair_pr_rx//o) {$mandatory  =$2;}
    if (s/$next_pair_pr_rx//o) {$type       =$2 || 'unknown';}
    if (s/$next_pair_pr_rx//o) {$default    =$2 || '&nbsp;';}
    if (s/$next_pair_pr_rx//o) {$constraints=$2 || '&nbsp;';}
    if (s/$next_pair_pr_rx//o) {$text       =$2 || '&nbsp;';}

    my $line=join("",
		  "\n<tr valign=top bgcolor='silver'>",
		  "<td><b>$parameter</b></td>",
		  "<td>$mandatory</td>",
		  "<td>",&sasref_label($type,"param","param:paramtypes",),
		  "</td>",
		  "<td>$default</td>",
		  "<td>$constraints</td>",
		  "</tr>\n",
		  "\n<tr valign=top>",
		  "<td colspan=5>$text<br>&nbsp;</td>",
		  "</tr>\n",
		  $_,
		  );
    $line=~s/\\par\b//mg;
    $line;
}



# --- error related macros
sub do_env_sasErrorEnv {		  

	
    my $attr="width=\"100%\" border=0 cellpadding=0 cellspacing=0";
    my $line=join("\n",
		  "\n<br><table $attr>",
		  $explain,
		  "@_",
		  $explain,
		  "</table>\n",);

    $line=~s/\\par\b//mg;
    $line;
}

sub do_cmd_sasErrorEnvNote {
    local($_) = @_;
    &l2hBugFixParsing(\$_);
    my $text;
    if (s/$next_pair_pr_rx//o) {$text  =$2 || '&nbsp;';}

    my $line=join("",
		  "\n<tr valign=top><td colspan=3>",
		  "&nbsp;<br>$text&nbsp;</td></tr>\n",
		  $_,
		  );
    $line=~s/\\par\b//mg;
    $line;
}

sub do_cmd_sasErrorEnvError
{
    local($_) = @_;
    my($label,$idx,$type,$comment,$other);

    &l2hBugFixParsing(\$_);
    if (s/$next_pair_pr_rx//o) {$label  =$2;}
    if (s/$next_pair_pr_rx//o) {$idx    =$2;}
    if (s/$next_pair_pr_rx//o) {$type   =$2;}
    if (s/$next_pair_pr_rx//o) {$comment=$2;}
    $other=$_;

    my $line="<tr valign=top bgcolor='silver'><td colspan=2><b>$label</b>$idx</td><td align=right><b><font color=\"#FF0000\">".
	$type."</font></b>&nbsp;</td></tr>";
    $line.="<tr valign=top><td>&nbsp;</td><td colspan=2>$comment<br>&nbsp;</td></tr>".
	$other;

    $line;
}
sub do_cmd_sasErrorEnvWarning
{
    local($_) = @_;
    my($label,$idx,$correction,$comment,$other);

    &l2hBugFixParsing(\$_);
    if (s/$next_pair_pr_rx//o) {$label     =$2;}
    if (s/$next_pair_pr_rx//o) {$idx       =$2;}
    if (s/$next_pair_pr_rx//o) {$correction=$2;}
    if (s/$next_pair_pr_rx//o) {$comment   =$2;}

    $other=$_;
    $comment.="\n<br><b>corrective action:</b> $correction" if $correction;

    my $line="<tr valign=top bgcolor='silver'><td colspan=2><b>$label</b>$idx</td><td align=right><b><font color=\"#CC6600\">warning</font></b>&nbsp;</td></tr>";    
    $line.="<tr valign=top><td>&nbsp;</td><td colspan=2>$comment<br>&nbsp;</td></tr>".$other;

    $line;
}


1;
