% ESA (C) 2000-2018 
%
% This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
%
%    SAS is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    SAS is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
\ProvidesClass{userguide}

\RequirePackage{fancyhdr}
\RequirePackage{epsfig}
\RequirePackage{ifthen}

\LoadClass{book}

\RequirePackage{html}

\setlength{\textwidth}{16cm}
\setlength{\textheight}{23.5cm}
\setlength{\topmargin}{-1cm}
\setlength{\oddsidemargin}{0cm}
\setlength{\evensidemargin}{0cm}
\setlength{\leftmargini}{2cm}

\setlength{\parindent}{0in}             % No indent at start of paragraphs
\setlength{\parskip}{\baselineskip}     % Blank line between paragraph

\renewcommand\floatpagefraction{0.5}
\renewcommand\dblfloatpagefraction{0.5}
\def\fps@figure{!htbp}

\setcounter{secnumdepth}{5}    % numbering level of sections
\setcounter{tocdepth}{1}       % appearance level in table of contents

\pagestyle{fancy}

\addtolength{\headheight}{15mm}
%\addtolength{\headsep}{0mm}

\lhead{
  \psfig{file=xmmsaslogo.eps,height=1.5cm}
  {\bfseries\large XMM-Newton Science Analysis System} \vskip -1\baselineskip
  }

% rhead is defined in \maketitlepage, see below

\cfoot{}                        %empy footer, no page numbers at bottom


%% Here we plug in our own maketitle

\renewcommand\maketitle{
\@startsection {section}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\normalfont\Large\bfseries}{\@title}
}

\newenvironment{abstract}{%
      \if@twocolumn
        \section*{\abstractname}%
      \else
        \small
        \begin{center}%
          {\bfseries \abstractname\vspace{-.5em}\vspace{\z@}}%
        \end{center}%
        \quotation
      \fi}
      {\if@twocolumn\else\endquotation\fi}

\newcommand\abstractname{Abstract}

\renewcommand\part{\if@openright\cleardoublepage\else\clearpage\fi
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}
\def\@chapter[#1]#2{\ifnum \c@secnumdepth >\m@ne
                       \if@mainmatter
                         \refstepcounter{chapter}%
                         \typeout{\@chapapp\space\thechapter.}%
                         \addcontentsline{toc}{chapter}%
                                   {\protect\numberline{\thechapter}#1}%
                       \else
                         \addcontentsline{toc}{chapter}{#1}%
                       \fi
                    \else
                      \addcontentsline{toc}{chapter}{#1}%
                    \fi
                    \chaptermark{#1}%
                    \addtocontents{lof}{\protect\addvspace{10\p@}}%
                    \addtocontents{lot}{\protect\addvspace{10\p@}}%
                    \if@twocolumn
                      \@topnewpage[\@makechapterhead{#2}]%
                    \else
                      \@makechapterhead{#2}%
                      \@afterheading
                    \fi}

\def\@makechapterhead#1{%
%  \vspace*{1\p@}%
  {\parindent \z@ \raggedright \normalfont
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
        \huge\bfseries\thechapter.\space #1
        \par\nobreak
      \fi
    \fi
    \vskip 10\p@
  }}

\renewcommand\chapter{\@startsection {section}{1}{\z@}%
                                   {-3.5ex \@plus -1ex \@minus -.2ex}%
                                   {2.3ex \@plus.2ex}%
                                   {\normalfont\Large\bfseries}}

\renewcommand\section{\@startsection{subsection}{2}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\large\bfseries}}

\renewcommand\subsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-3.25ex\@plus -1ex \@minus -.2ex}%
                                     {1.5ex \@plus .2ex}%
                                     {\normalfont\normalsize\bfseries}}

\renewcommand\subsubsection{\@startsection{paragraph}{4}{\z@}%
                                    {3.25ex \@plus1ex \@minus.2ex}%
                                    {1.0ex \@plus .2ex}%
                                    {\normalfont\normalsize\bfseries}}

\renewcommand\paragraph{\@startsection{subparagraph}{5}{\parindent}%
                                       {3.25ex \@plus1ex \@minus .2ex}%
                                       {-1em}%
                                      {\normalfont\normalsize\bfseries}}

%
% Developer's note section
\newenvironment{developernotes}{%
  \section{Developer's notes}
}{}

%
% Implementer's notes
\newenvironment{implementersnotes}{%
  \section{Implementer's and Maintainer's notes}
}{}

%
% Change history
\newenvironment{changehistory}{%
  \section{Change history}
  }{}

%
% SAS version
\newenvironment{sasversion}{%
  \section{Status}
  }{}

%
% Task errors - environment and commands
\newenvironment{taskerrors}{%
  \section{Errors}
  The following error conditions can occur:
  \begin{description}}{\end{description}}

\newcommand{\fatal}[2]{\error{#1}{#2}}
\newcommand{\warn}[3]{\warning{#1}{#2}{#3}}

\newcommand{\warning}[3]{\item \textbf{warning}: #1\\
  \textbf{corrective action}: #2\\
  \textbf{explanation}: #3}

\newcommand{\error}[2]{\item \textbf{error}: #1\\
  \textbf{explanation}: #2}
 

%
% Task parameters - environment and commands
\newenvironment{taskparameters}{%
  \section{Parameters}
  The following command line parameters are recognized by the task: 
  \begin{description}}{\end{description}}

\newcommand{\taskparm}[4]{%
\item #1\\
  default value = #2\\
  type = #3\\
  constraints = #4}
  

\newcommand{\mandparm}[5]{\taskparm{\textbf{#1} \textit{(mandatory)}}{#2}{#3}{#4}\mbox{}\\#5}

\newcommand{\optparm}[5]{\taskparm{\textbf{#1} \textit{(optional)}}{#2}{#3}{#4}\mbox{}\\#5}

\newcommand{\remark}[1]{\newline\textbf{Remark:} \textit{#1}\newline}

\RequirePackage{version} 
\excludeversion{developernotes}
\excludeversion{implementersnotes}
\excludeversion{changehistory}
\excludeversion{sasversion}
\excludeversion{abstract}
\renewcommand{\author}[1]{}%
\renewcommand{\date}[1]{}%
\renewcommand{\remark}[1]{}


\newcommand\maketitlepage{
\null
\vskip 2em%
\begin{center}
{\Huge\bfseries \@title \par}
\end{center}
\rhead{}
\newpage
\rhead{
  \begin{tabular}{ll}
    Page:       & \thepage
  \end{tabular}
  }


}
